---
title: "Ibis Birdbrain"
description: "the portable Python LM-powered data bot"
repo-actions: false
code-annotations: hover
format:
  html:
    toc: false
about:
  id: about
  template: jolla
  image: images/logo.png
  links:
    - icon: info-circle
      text: Why Ibis Birdbrain?
      href: why.qmd
    - icon: download
      text: Installation
      href: install.qmd
    - icon: book
      text: "Tutorial: getting started"
      href: tutorials/python.qmd
    - icon: github
      text: GitHub
      href: https://github.com/ibis-project/ibis-birdbrain
    - icon: slack
      text: Chat
      href: https://ibis-project.zulipchat.com
    # - icon: rss
    #   text: RSS
    #   href: https://ibis-project.github.io/ibis-birdbrain/posts.xml
---

::: {#about}
:::

::: {.callout-warning}
Ibis Birdbrain is highly experimental and currently under construction by slow humans. Please check back soon!
:::
